@@ -15,8 +15,6 @@
  *                                                                         *
  ***************************************************************************/
 
-
-
 #ifndef TEST_SKYPOINT_H
 #define TEST_SKYPOINT_H
 
@@ -33,16 +31,15 @@
  * @author Akarsh Simha <akarsh.simha@kdemail.net>
  */
 
-class TestSkyPoint : public QObject {
-
+class TestSkyPoint : public QObject
+{
     Q_OBJECT
 
-public:
+  public:
+    TestSkyPoint() : QObject(){};
+    ~TestSkyPoint(){};
 
-    TestSkyPoint() : QObject() {};
-    ~TestSkyPoint() {};
-
-private slots:
+  private slots:
     void testPrecession();
 };
 
