@@ -17,7 +17,6 @@ class KConfigDialog;
 
 namespace Ekos
 {
-
 /**
  * @class OpsGuide
  *
@@ -29,26 +28,13 @@ class OpsGuide : public QFrame, public Ui::OpsGuide
 {
     Q_OBJECT
 
-public:
+  public:
     explicit OpsGuide();
     ~OpsGuide();
 
-protected:
-    void showEvent(QShowEvent *);
-
-private slots:
-
-    void slotApply();
-    void slotLoadSettings(int guiderType);
-
-signals:
-    void guiderTypeChanged(int guiderType);
-
-private:
-    KConfigDialog *m_ConfigDialog;    
+  private:
+    KConfigDialog *m_ConfigDialog;
 };
-
 }
 
 #endif
-
