@@ -18,27 +18,53 @@
 
 class SchedulerJob
 {
-public:
+  public:
     SchedulerJob();
     ~SchedulerJob();
 
-    typedef enum { JOB_IDLE, JOB_EVALUATION, JOB_SCHEDULED, JOB_BUSY, JOB_ERROR, JOB_ABORTED, JOB_INVALID, JOB_COMPLETE } JOBStatus;
-    typedef enum { STAGE_IDLE, STAGE_SLEWING, STAGE_SLEW_COMPLETE, STAGE_FOCUSING, STAGE_FOCUS_COMPLETE, STAGE_ALIGNING, STAGE_ALIGN_COMPLETE, STAGE_RESLEWING, STAGE_RESLEWING_COMPLETE,
-                   STAGE_POSTALIGN_FOCUSING, STAGE_POSTALIGN_FOCUSING_COMPLETE, STAGE_GUIDING, STAGE_GUIDING_COMPLETE, STAGE_CAPTURING, STAGE_COMPLETE} JOBStage;
+    typedef enum {
+        JOB_IDLE,
+        JOB_EVALUATION,
+        JOB_SCHEDULED,
+        JOB_BUSY,
+        JOB_ERROR,
+        JOB_ABORTED,
+        JOB_INVALID,
+        JOB_COMPLETE
+    } JOBStatus;
+    typedef enum {
+        STAGE_IDLE,
+        STAGE_SLEWING,
+        STAGE_SLEW_COMPLETE,
+        STAGE_FOCUSING,
+        STAGE_FOCUS_COMPLETE,
+        STAGE_ALIGNING,
+        STAGE_ALIGN_COMPLETE,
+        STAGE_RESLEWING,
+        STAGE_RESLEWING_COMPLETE,
+        STAGE_POSTALIGN_FOCUSING,
+        STAGE_POSTALIGN_FOCUSING_COMPLETE,
+        STAGE_GUIDING,
+        STAGE_GUIDING_COMPLETE,
+        STAGE_CAPTURING,
+        STAGE_COMPLETE
+    } JOBStage;
     //typedef enum { FITS_IDLE, FITS_SOLVING, FITS_COMPLETE, FITS_ERROR } FITSStatus;
     typedef enum { START_ASAP, START_CULMINATION, START_AT } StartupCondition;
     typedef enum { FINISH_SEQUENCE, FINISH_REPEAT, FINISH_LOOP, FINISH_AT } CompletionCondition;
-    typedef enum { USE_NONE  = 0,
-                   USE_TRACK = 1 << 0,
-                   USE_FOCUS = 1 << 1,
-                   USE_ALIGN = 1 << 2,
-                   USE_GUIDE = 1 << 3 } StepPipeline;
+    typedef enum {
+        USE_NONE  = 0,
+        USE_TRACK = 1 << 0,
+        USE_FOCUS = 1 << 1,
+        USE_ALIGN = 1 << 2,
+        USE_GUIDE = 1 << 3
+    } StepPipeline;
 
     QString getName() const;
     void setName(const QString &value);
 
     void setTargetCoords(dms ra, dms dec);
-    SkyPoint & getTargetCoords();
+    SkyPoint &getTargetCoords();
 
     StartupCondition getStartupCondition() const;
     void setStartupCondition(const StartupCondition &value);
@@ -122,8 +148,7 @@ public:
     uint16_t getRepeatsRemaining() const;
     void setRepeatsRemaining(const uint16_t &value);
 
-private:
-
+  private:
     QString name;
     SkyPoint targetCoords;
     JOBStatus state;
@@ -148,17 +173,16 @@ private:
 
     StepPipeline stepPipeline;
 
-    QTableWidgetItem* statusCell, *startupCell, *estimatedTimeCell;
+    QTableWidgetItem *statusCell, *startupCell, *estimatedTimeCell;
 
     int score;
     int16_t culminationOffset;
     uint8_t priority;
     int64_t estimatedTime;
-    uint16_t repeatsRequired=0, repeatsRemaining=0;
+    uint16_t repeatsRequired = 0, repeatsRemaining = 0;
     bool timeSlotAllocated;
     bool inSequenceFocus;
 
-    double Dawn, Dusk;
     QString dateTimeDisplayFormat;
     QString profile;
 
