@@ -7,33 +7,24 @@
     version 2 of the License, or (at your option) any later version.
  */
 
-#ifndef GUIMANAGER_H
-#define GUIMANAGER_H
+#pragma once
 
-#include <QGridLayout>
-#include <QFrame>
-#include <QHBoxLayout>
-#include <QLabel>
-#include <QVBoxLayout>
-#include <QTabWidget>
-#include <QPointer>
+#include <QList>
+#include <QWidget>
 
-#include <indibase.h>
-
-#include "clientmanager.h"
-
-class QLabel;
-class QHBoxLayout;
-class QVBoxLayout;
-class QFrame;
+class QCloseEvent;
+class QHideEvent;
+class QPushButton;
+class QShowEvent;
 class QString;
 class QTabWidget;
-class QGridLayout;
-class QPushButton;
-class FITSViewer;
+class QVBoxLayout;
 
 class INDI_D;
 
+class ClientManager;
+class DeviceInfo;
+
 /**
  * @class GUIManager
  * GUIManager creates the INDI Control Panel upon receiving a new device. Each device is displayed
@@ -45,45 +36,42 @@ class INDI_D;
 class GUIManager : public QWidget
 {
     Q_OBJECT
-public:
-
+  public:
     static GUIManager *Instance();
 
     void updateStatus();
 
-
-    INDI_D * findGUIDevice(const QString &deviceName);
+    INDI_D *findGUIDevice(const QString &deviceName);
 
     void addClient(ClientManager *cm);
     void removeClient(ClientManager *cm);
 
-    QList<INDI_D*> getDevices() { return guidevices; }
+    QList<INDI_D *> getDevices() { return guidevices; }
 
-    int size() { return guidevices.size(); }    
+    int size() { return guidevices.size(); }
 
-protected:
+  protected:
     void closeEvent(QCloseEvent *);
     void hideEvent(QHideEvent *);
     void showEvent(QShowEvent *);
 
   private:
     /*****************************************************************
-    * GUI stuff
-    ******************************************************************/
-    QVBoxLayout	*mainLayout;
-    QTabWidget	*mainTabWidget;
-    QPushButton  *clearB;
-    QPushButton  *closeB;
-    GUIManager(QWidget * parent = 0);
+     * GUI stuff
+     ******************************************************************/
+    QVBoxLayout *mainLayout;
+    QTabWidget *mainTabWidget;
+    QPushButton *clearB;
+    QPushButton *closeB;
+    GUIManager(QWidget *parent = 0);
 
-    static GUIManager * _GUIManager;
+    static GUIManager *_GUIManager;
     QList<ClientManager *> clients;
-    QList<INDI_D*> guidevices;    
+    QList<INDI_D *> guidevices;
 
   public slots:
+    void changeAlwaysOnTop(Qt::ApplicationState state);
     void clearLog();
     void buildDevice(DeviceInfo *di);
     void removeDevice(DeviceInfo *di);
 };
-
-#endif // GUIMANAGER_H
