@@ -14,7 +14,6 @@
 
 namespace ISD
 {
-
 /**
  * @class Focuser
  * Focuser class handles control of INDI focuser devices. Both relative and absolute focusers can be controlled.
@@ -26,17 +25,21 @@ class Focuser : public DeviceDecorator
 {
     Q_OBJECT
 
-public:
-    enum FocusDirection { FOCUS_INWARD, FOCUS_OUTWARD };
+  public:
+    enum FocusDirection
+    {
+        FOCUS_INWARD,
+        FOCUS_OUTWARD
+    };
 
-    Focuser(GDInterface *iPtr) : DeviceDecorator(iPtr) { dType = KSTARS_FOCUSER;}
+    Focuser(GDInterface *iPtr) : DeviceDecorator(iPtr) { dType = KSTARS_FOCUSER; }
 
     void processSwitch(ISwitchVectorProperty *svp);
-    void processText(ITextVectorProperty* tvp);
+    void processText(ITextVectorProperty *tvp);
     void processNumber(INumberVectorProperty *nvp);
     void processLight(ILightVectorProperty *lvp);
 
-    DeviceFamily getType() { return dType;}
+    DeviceFamily getType() { return dType; }
 
     bool focusIn();
     bool focusOut();
@@ -46,11 +49,10 @@ public:
 
     bool canAbsMove();
     bool canRelMove();
+    bool canTimerMove();
 
     bool getFocusDirection(FocusDirection *dir);
-
 };
-
 }
 
 #endif // INDIFOCUSER_H
