@@ -9,17 +9,14 @@
     Handle INDI Standard properties.
  */
 
-#ifndef INDISTD_H
-#define INDISTD_H
+#pragma once
+
+#include "indicommon.h"
 
 #include <indiproperty.h>
+
 #include <QObject>
-
-#include "skypoint.h"
-#include "indicommon.h"
-#include "fitsviewer/fitscommon.h"
-
-#include "config-kstars.h"
+#include <QVariant>
 
 #define MAXINDIFILENAME 512
 
@@ -31,20 +28,18 @@ class QTimer;
 // INDI Standard Device Namespace
 namespace ISD
 {
-
-
 class GDSetCommand : public QObject
 {
     Q_OBJECT
 
-public:
-    GDSetCommand(INDI_PROPERTY_TYPE inPropertyType, const QString & inProperty, const QString & inElement, QVariant qValue, QObject *parent);
-    INDI_PROPERTY_TYPE   propType;
+  public:
+    GDSetCommand(INDI_PROPERTY_TYPE inPropertyType, const QString &inProperty, const QString &inElement,
+                 QVariant qValue, QObject *parent);
+    INDI_PROPERTY_TYPE propType;
 
     QString indiProperty;
     QString indiElement;
     QVariant elementValue;
-
 };
 
 /**
@@ -61,49 +56,50 @@ class GDInterface : public QObject
 {
     Q_OBJECT
 
-public:
+  public:
     // Property handling
-    virtual void registerProperty(INDI::Property *prop) =0;
-    virtual void removeProperty(INDI::Property *prop) =0;
-    virtual void processSwitch(ISwitchVectorProperty *svp)=0;
-    virtual void processText(ITextVectorProperty* tvp)=0;
-    virtual void processNumber(INumberVectorProperty *nvp)=0;
-    virtual void processLight(ILightVectorProperty *lvp)=0;
-    virtual void processBLOB(IBLOB *bp)=0;
-    virtual void processMessage(int messageID)=0;
+    virtual void registerProperty(INDI::Property *prop)    = 0;
+    virtual void removeProperty(INDI::Property *prop)      = 0;
+    virtual void processSwitch(ISwitchVectorProperty *svp) = 0;
+    virtual void processText(ITextVectorProperty *tvp)     = 0;
+    virtual void processNumber(INumberVectorProperty *nvp) = 0;
+    virtual void processLight(ILightVectorProperty *lvp)   = 0;
+    virtual void processBLOB(IBLOB *bp)                    = 0;
+    virtual void processMessage(int messageID)             = 0;
 
     // Accessors
-    virtual QList<INDI::Property *> getProperties() =0;
-    virtual DeviceFamily getType()=0;
-    virtual DriverInfo * getDriverInfo() = 0;
-    virtual DeviceInfo * getDeviceInfo() = 0;
-    virtual INDI::BaseDevice* getBaseDevice()=0;
+    virtual QList<INDI::Property *> getProperties() = 0;
+    virtual DeviceFamily getType()                  = 0;
+    virtual DriverInfo *getDriverInfo()             = 0;
+    virtual DeviceInfo *getDeviceInfo()             = 0;
+    virtual INDI::BaseDevice *getBaseDevice()       = 0;
 
     // Convenience functions
-    virtual bool setConfig(INDIConfig tConfig)=0;
-    virtual const char *getDeviceName()=0;
-    virtual bool isConnected()=0;
-    virtual bool getMinMaxStep(const QString & propName, const QString & elementName, double *min, double *max, double *step)=0;
-    virtual IPState getState(const QString &propName)=0;
-    virtual IPerm getPermission(const QString &propName)=0;
+    virtual bool setConfig(INDIConfig tConfig)           = 0;
+    virtual const char *getDeviceName()                  = 0;
+    virtual bool isConnected()                           = 0;
+    virtual bool getMinMaxStep(const QString &propName, const QString &elementName, double *min, double *max,
+                               double *step)             = 0;
+    virtual IPState getState(const QString &propName)    = 0;
+    virtual IPerm getPermission(const QString &propName) = 0;
 
     virtual ~GDInterface() {}
 
-protected:
+  protected:
     DeviceFamily dType;
     QList<INDI::Property *> properties;
 
-public slots:
-    virtual bool Connect()=0;
-    virtual bool Disconnect()=0;
-    virtual bool runCommand(int command, void *ptr=NULL)=0;
-    virtual bool setProperty(QObject *)=0;
+  public slots:
+    virtual bool Connect()                                    = 0;
+    virtual bool Disconnect()                                 = 0;
+    virtual bool runCommand(int command, void *ptr = nullptr) = 0;
+    virtual bool setProperty(QObject *)                       = 0;
 
-signals:
+  signals:
     void Connected();
     void Disconnected();
     void switchUpdated(ISwitchVectorProperty *svp);
-    void textUpdated(ITextVectorProperty* tvp);
+    void textUpdated(ITextVectorProperty *tvp);
     void numberUpdated(INumberVectorProperty *nvp);
     void lightUpdated(ILightVectorProperty *lvp);
     void BLOBUpdated(IBLOB *bp);
@@ -111,8 +107,6 @@ signals:
 
     void propertyDefined(INDI::Property *prop);
     void propertyDeleted(INDI::Property *prop);
-
-
 };
 
 /**
@@ -129,15 +123,14 @@ class GenericDevice : public GDInterface
 {
     Q_OBJECT
 
-public:
-
-    GenericDevice(DeviceInfo* idv);
+  public:
+    GenericDevice(DeviceInfo *idv);
     ~GenericDevice();
 
     virtual void registerProperty(INDI::Property *prop);
     virtual void removeProperty(INDI::Property *prop);
     virtual void processSwitch(ISwitchVectorProperty *svp);
-    virtual void processText(ITextVectorProperty* tvp);
+    virtual void processText(ITextVectorProperty *tvp);
     virtual void processNumber(INumberVectorProperty *nvp);
     virtual void processLight(ILightVectorProperty *lvp);
     virtual void processBLOB(IBLOB *bp);
@@ -145,33 +138,33 @@ public:
 
     virtual DeviceFamily getType() { return dType; }
     virtual const char *getDeviceName();
-    virtual DriverInfo * getDriverInfo() { return driverInfo;}
-    virtual DeviceInfo * getDeviceInfo() { return deviceInfo;}
+    virtual DriverInfo *getDriverInfo() { return driverInfo; }
+    virtual DeviceInfo *getDeviceInfo() { return deviceInfo; }
     virtual QList<INDI::Property *> getProperties() { return properties; }
 
-
     virtual bool setConfig(INDIConfig tConfig);
     virtual bool isConnected() { return connected; }
-    virtual INDI::BaseDevice* getBaseDevice() { return baseDevice;}
-    virtual bool getMinMaxStep(const QString & propName, const QString & elementName, double *min, double *max, double *step);
+    virtual INDI::BaseDevice *getBaseDevice() { return baseDevice; }
+    virtual bool getMinMaxStep(const QString &propName, const QString &elementName, double *min, double *max,
+                               double *step);
     virtual IPState getState(const QString &propName);
     virtual IPerm getPermission(const QString &propName);
 
-public slots:
+  public slots:
     virtual bool Connect();
     virtual bool Disconnect();
-    virtual bool runCommand(int command, void *ptr=NULL);
+    virtual bool runCommand(int command, void *ptr = nullptr);
     virtual bool setProperty(QObject *);
 
-protected slots:
+  protected slots:
     virtual void resetWatchdog();
 
-protected:
+  protected:
     void createDeviceInit();
     void updateTime();
     void updateLocation();
 
-private:
+  private:
     bool connected;
     DriverInfo *driverInfo;
     DeviceInfo *deviceInfo;
@@ -179,7 +172,6 @@ private:
     ClientManager *clientManager;
     QTimer *watchDogTimer;
     char BLOBFilename[MAXINDIFILENAME];
-
 };
 
 /**
@@ -192,16 +184,14 @@ class DeviceDecorator : public GDInterface
 {
     Q_OBJECT
 
-public:
-
-
+  public:
     DeviceDecorator(GDInterface *iPtr);
     ~DeviceDecorator();
 
     virtual void registerProperty(INDI::Property *prop);
     virtual void removeProperty(INDI::Property *prop);
     virtual void processSwitch(ISwitchVectorProperty *svp);
-    virtual void processText(ITextVectorProperty* tvp);
+    virtual void processText(ITextVectorProperty *tvp);
     virtual void processNumber(INumberVectorProperty *nvp);
     virtual void processLight(ILightVectorProperty *lvp);
     virtual void processBLOB(IBLOB *bp);
@@ -213,26 +203,24 @@ public:
     virtual bool isConnected();
     const char *getDeviceName();
     DriverInfo *getDriverInfo();
-    DeviceInfo * getDeviceInfo();
+    DeviceInfo *getDeviceInfo();
     QList<INDI::Property *> getProperties();
-    virtual INDI::BaseDevice* getBaseDevice();
+    virtual INDI::BaseDevice *getBaseDevice();
 
-    bool getMinMaxStep(const QString & propName, const QString & elementName, double *min, double *max, double *step);
+    bool getMinMaxStep(const QString &propName, const QString &elementName, double *min, double *max, double *step);
     IPState getState(const QString &propName);
     IPerm getPermission(const QString &propName);
 
-
-public slots:
+  public slots:
     virtual bool Connect();
     virtual bool Disconnect();
-    virtual bool runCommand(int command, void *ptr=NULL);
+    virtual bool runCommand(int command, void *ptr = nullptr);
     virtual bool setProperty(QObject *);
 
-protected:
+  protected:
     INDI::BaseDevice *baseDevice;
     ClientManager *clientManager;
     GDInterface *interfacePtr;
-
 };
 
 /**
@@ -246,22 +234,18 @@ protected:
  */
 class ST4
 {
-public:
+  public:
     ST4(INDI::BaseDevice *bdv, ClientManager *cm);
     ~ST4();
 
-    bool doPulse(GuideDirection ra_dir, int ra_msecs, GuideDirection dec_dir, int dec_msecs );
-    bool doPulse(GuideDirection dir, int msecs );
+    bool doPulse(GuideDirection ra_dir, int ra_msecs, GuideDirection dec_dir, int dec_msecs);
+    bool doPulse(GuideDirection dir, int msecs);
     void setDECSwap(bool enable);
     const char *getDeviceName();
 
-private:
+  private:
     INDI::BaseDevice *baseDevice;
     ClientManager *clientManager;
     bool swapDEC;
-
 };
-
 }
-
-#endif // INDISTD_H
