@@ -7,16 +7,15 @@
     version 2 of the License, or (at your option) any later version.
  */
 
-#ifndef INDITELESCOPE_H
-#define INDITELESCOPE_H
+#pragma once
 
 #include "indistd.h"
+#include "skypoint.h"
 
 class SkyObject;
 
 namespace ISD
 {
-
 /**
  * @class Telescope
  * device handle controlling telescope. It can slew and sync to a specific sky point and supports all standard propreties with INDI
@@ -28,22 +27,30 @@ class Telescope : public DeviceDecorator
 {
     Q_OBJECT
 
-public:
+  public:
     Telescope(GDInterface *iPtr);
     ~Telescope();
 
     typedef enum { MOTION_NORTH, MOTION_SOUTH } TelescopeMotionNS;
     typedef enum { MOTION_WEST, MOTION_EAST } TelescopeMotionWE;
     typedef enum { MOTION_START, MOTION_STOP } TelescopeMotionCommand;
-    typedef enum { MOUNT_IDLE, MOUNT_SLEWING, MOUNT_TRACKING, MOUNT_PARKING, MOUNT_PARKED, MOUNT_ERROR } TelescopeStatus;
+    typedef enum {
+        MOUNT_IDLE,
+        MOUNT_MOVING,
+        MOUNT_SLEWING,
+        MOUNT_TRACKING,
+        MOUNT_PARKING,
+        MOUNT_PARKED,
+        MOUNT_ERROR
+    } TelescopeStatus;
     typedef enum { PARK_UNKNOWN, PARK_PARKED, PARK_PARKING, PARK_UNPARKING, PARK_UNPARKED } ParkStatus;
 
     void registerProperty(INDI::Property *prop);
     void processSwitch(ISwitchVectorProperty *svp);
-    void processText(ITextVectorProperty* tvp);
+    void processText(ITextVectorProperty *tvp);
     void processNumber(INumberVectorProperty *nvp);
 
-    DeviceFamily getType() { return dType;}
+    DeviceFamily getType() { return dType; }
 
     // Coordinates
     bool getEqCoords(double *ra, double *dec);
@@ -62,11 +69,12 @@ public:
     bool MoveWE(TelescopeMotionWE dir, TelescopeMotionCommand cmd);
     bool isSlewing();
     bool isInMotion();
+    QString getManualMotionString() const;
 
     // Guiding
     bool canGuide();
-    bool doPulse(GuideDirection ra_dir, int ra_msecs, GuideDirection dec_dir, int dec_msecs );
-    bool doPulse(GuideDirection dir, int msecs );
+    bool doPulse(GuideDirection ra_dir, int ra_msecs, GuideDirection dec_dir, int dec_msecs);
+    bool doPulse(GuideDirection dir, int msecs);
 
     // Parking
     bool canPark();
@@ -75,7 +83,7 @@ public:
     // Status
     ParkStatus getParkStatus() { return parkStatus; }
     TelescopeStatus getStatus();
-    static const QString getStatusString(TelescopeStatus status);
+    const QString getStatusString(TelescopeStatus status);
 
     // Altitude Limits
     void setAltLimits(double minAltitude, double maxAltitude);
@@ -83,30 +91,31 @@ public:
     // Alignment Model
     bool setAlignmentModelEnabled(bool enable);
     bool clearAlignmentModel();
+    bool hasAlignmentModel() { return m_hasAlignmentModel; }
 
-protected:
+  protected:
     bool sendCoords(SkyPoint *ScopeTarget);
 
-public slots:
-    virtual bool runCommand(int command, void *ptr=NULL);
+  public slots:
+    virtual bool runCommand(int command, void *ptr = nullptr);
     bool Abort();
     bool Park();
     bool UnPark();
     bool setSlewRate(int index);
 
-signals:
+  signals:
     void newTarget(const QString &);
 
-private:
+  private:
     SkyPoint currentCoord;
-    double minAlt,maxAlt;
+    double minAlt, maxAlt;
     ParkStatus parkStatus = PARK_UNKNOWN;
     IPState EqCoordPreviousState;
-    QTimer *centerLockTimer=NULL;
-    SkyObject *currentObject=NULL;
-
+    QTimer *centerLockTimer  = nullptr;
+    SkyObject *currentObject = nullptr;
+    bool inManualMotion      = false;
+    bool m_hasAlignmentModel = false;
+    IPState NSPreviousState  = IPS_IDLE;
+    IPState WEPreviousState  = IPS_IDLE;
 };
-
 }
-
-#endif // INDITELESCOPE_H
