@@ -22,7 +22,6 @@
 
 class DriverInfo;
 
-
 /**
  * @class ServerManager
  * ServerManager is responsible for starting and shutting local INDI servers.
@@ -31,23 +30,27 @@ class DriverInfo;
  */
 class ServerManager : public QObject
 {
-
     Q_OBJECT
 
-public:
-
-    enum { INDI_DEVICE_NOT_FOUND=-1, INDI_PROPERTY_INVALID=-2, INDI_PROPERTY_DUPLICATED = -3, INDI_DISPATCH_ERROR=-4 };
+  public:
+    enum
+    {
+        INDI_DEVICE_NOT_FOUND    = -1,
+        INDI_PROPERTY_INVALID    = -2,
+        INDI_PROPERTY_DUPLICATED = -3,
+        INDI_DISPATCH_ERROR      = -4
+    };
 
     ServerManager(QString inHost, uint inPort);
-      ~ServerManager();
+    ~ServerManager();
 
     bool start();
     void stop();
     void terminate();
 
-    const QString & getLogBuffer() { return serverBuffer; }
-    const QString & getHost() { return host;}
-    const QString & getPort() { return port;}
+    const QString &getLogBuffer() { return serverBuffer; }
+    const QString &getHost() { return host; }
+    const QString &getPort() { return port; }
 
     bool startDriver(DriverInfo *dv);
     void stopDriver(DriverInfo *dv);
@@ -61,34 +64,31 @@ public:
 
     bool isDriverManaged(DriverInfo *);
 
-private:
+  private:
+    QTcpSocket serverSocket;
+    LilXML *XMLParser;
+    QString host;
+    QString port;
+    QString serverBuffer;
+    QProcess *serverProcess;
 
-    QTcpSocket		 serverSocket;
-    LilXML		 *XMLParser;
-    QString		 host;
-    QString		 port;
-    QString 		 serverBuffer;
-    QProcess 		 *serverProcess;
-
-    ServerMode          mode;
-    bool        driverCrashed;
+    ServerMode mode;
+    bool driverCrashed;
 
     QList<DriverInfo *> managedDrivers;
 
-    QFile               indiFIFO;
+    QFile indiFIFO;
 
-public slots:
+  public slots:
     void connectionSuccess();
     void processServerError(QProcess::ProcessError);
     void processStandardError();
 
-signals:
+  signals:
     void serverFailure(ServerManager *);
     void newServerLog();
     void started();
     void finished(int exit_code, QProcess::ExitStatus exit_status);
-
-
 };
 
 #endif // SERVERMANAGER_H
