@@ -16,31 +16,34 @@
 #include "indi/indistd.h"
 #include "ui_telescopewizard.h"
 
-class KStars;
-class QTimer;
-class INDI_D;
 class DriverInfo;
 
-class KProgressDialog;
+class QProgressDialog;
 
 class telescopeWizardProcess : public QDialog
 {
-
     Q_OBJECT
 
-public:
-    explicit telescopeWizardProcess( QWidget* parent = 0, const char* name = 0);
+  public:
+    explicit telescopeWizardProcess(QWidget *parent = 0, const char *name = 0);
     ~telescopeWizardProcess();
 
     unsigned int currentPage;
-    enum { INTRO_P=0, MODEL_P=1, TELESCOPE_P=2, LOCAL_P=3, PORT_P=4 };
+    enum
+    {
+        INTRO_P     = 0,
+        MODEL_P     = 1,
+        TELESCOPE_P = 2,
+        LOCAL_P     = 3,
+        PORT_P      = 4
+    };
 
-private:   
+  private:
     Ui::telescopeWizard *ui;
 
     ISD::GDInterface *scopeDevice;
 
-    KProgressDialog *progressScan;
+    QProgressDialog *progressScan;
 
     QStringList portList;
     QString currentDevice;
@@ -57,7 +60,7 @@ private:
     void establishLink();
     void Reset();
 
-public slots:
+  public slots:
     void cancelCheck();
     void processNext();
     void processBack();
@@ -66,7 +69,6 @@ public slots:
     void processTelescope(ISD::GDInterface *);
     void scanPorts();
     void linkSuccess();
-
 };
 
 #endif
