@@ -34,27 +34,28 @@ class QSGSimpleTextureNode;
 
 class RootNode;
 
-class ConstellationArtNode : public SkyNode  {
-public:
+class ConstellationArtNode : public SkyNode
+{
+  public:
     /**
-     * @short Constructor
-     * @param obj - a pointer to ConstellationsArt object that is represented by this node
-     */
+         * @short Constructor
+         * @param obj - a pointer to ConstellationsArt object that is represented by this node
+         */
     ConstellationArtNode(ConstellationsArt *obj);
     /**
-     * @short changePos change the position of this node
-     * @param pos - new position
-     * @param positionangle - an angle of ConstellationsArt image rotation
-     */
+         * @short changePos change the position of this node
+         * @param pos - new position
+         * @param positionangle - an angle of ConstellationsArt image rotation
+         */
     void changePos(QPointF pos, double positionangle);
 
     virtual void update() override;
     virtual void hide() override;
-private:
+
+  private:
     RootNode *m_rootNode;
     ConstellationsArt *m_art;
     QSGSimpleTextureNode *m_texture;
 };
 
 #endif
-
