@@ -13,27 +13,30 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#ifndef SKYPOLYGONNODE_H_
-#define SKYPOLYGONNODE_H_
+#pragma once
+
 #include "skynode.h"
 
 class PolyNode;
 
-    /** @class SkyPolygonNode
-     *
-     * @short A SkyNode derived class that represents polygon (either filled or non-filled)
-     * One of the applications of this class is drawing of Milky Way.
-     * @author Artem Fedoskin
-     * @version 1.0
-     */
+/**
+ *
+ * @class SkyPolygonNode
+ *
+ * @short A SkyNode derived class that represents polygon (either filled or non-filled)
+ * One of the applications of this class is drawing of Milky Way.
+ * @author Artem Fedoskin
+ * @version 1.0
+ */
 
-class SkyPolygonNode : public SkyNode {
-public:
+class SkyPolygonNode : public SkyNode
+{
+  public:
     /**
      * @short Constructor.
      * @param list - Used of lines that comprise polygon
      */
-    SkyPolygonNode(LineList* list);
+    SkyPolygonNode(LineList *list);
 
     /**
      * @short Update position and visibility of this polygon.
@@ -45,12 +48,8 @@ public:
     LineList *lineList() { return m_list; }
 
     void setColor(QColor color);
-private:
-    LineList *m_list;
-    PolyNode *m_polygonNode;
+
+  private:
+    LineList *m_list { nullptr };
+    PolyNode *m_polygonNode { nullptr };
 };
-
-
-#endif
-
-
