@@ -19,18 +19,19 @@
 #include <QSGSimpleTextureNode>
 #include "skynode.h"
 
-TrixelNode::TrixelNode(Trixel trixel)
-    :m_trixel(trixel)
+TrixelNode::TrixelNode(Trixel trixel) : m_trixel(trixel)
 {
-
 }
 
-void TrixelNode::deleteAllChildNodes() {
+void TrixelNode::deleteAllChildNodes()
+{
     QLinkedList<QPair<SkyObject *, SkyNode *>>::iterator i = m_nodes.begin();
 
-    while(i != m_nodes.cend()) {
+    while (i != m_nodes.cend())
+    {
         SkyNode *node = (*i).second;
-        if(node) {
+        if (node)
+        {
             removeChildNode(node);
             delete node;
 
@@ -40,12 +41,14 @@ void TrixelNode::deleteAllChildNodes() {
     }
 }
 
-void TrixelNode::hide() {
+void TrixelNode::hide()
+{
     m_hideCount++;
     SkyOpacityNode::hide();
 }
 
-void TrixelNode::show() {
+void TrixelNode::show()
+{
     SkyOpacityNode::show();
     m_hideCount = 0;
 }
