@@ -15,8 +15,7 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef CONSTELLATION_BOUNDARY_LINES_H
-#define CONSTELLATION_BOUNDARY_LINES_H
+#pragma once
 
 #include "noprecessindex.h"
 
@@ -27,9 +26,8 @@ class PolyList;
 class ConstellationBoundary;
 class KSFileReader;
 
-
-typedef QVector<PolyList*>        PolyListList;
-typedef QVector<PolyListList*>    PolyIndex;
+typedef QVector<std::shared_ptr<PolyList>> PolyListList;
+typedef QVector<std::shared_ptr<PolyListList>> PolyIndex;
 
 /**
  * @class ConstellationBoundary
@@ -40,40 +38,39 @@ typedef QVector<PolyListList*>    PolyIndex;
  */
 class ConstellationBoundaryLines : public NoPrecessIndex
 {
-public:
-    /** @short Constructor
-     * Simply adds all of the coordinate grid circles
-     * (meridians and parallels)
+  public:
+    /**
+     * @short Constructor
+     * Simply adds all of the coordinate grid circles (meridians and parallels)
      * @p parent Pointer to the parent SkyComposite object
      *
-     * Reads the constellation boundary data from cbounds.dat.
-     * The boundary data is defined by a series of RA,Dec coordinate pairs
-     * defining the "nodes" of the boundaries.  The nodes are organized into
-     * "segments", such that each segment represents a continuous series
+     * Reads the constellation boundary data from cbounds.dat. The boundary data is defined by
+     * a series of RA,Dec coordinate pairs defining the "nodes" of the boundaries. The nodes are
+     * organized into "segments", such that each segment represents a continuous series
      * of boundary-line intervals that divide two particular constellations.
      */
-    explicit ConstellationBoundaryLines( SkyComposite *parent );
+    explicit ConstellationBoundaryLines(SkyComposite *parent);
+    virtual ~ConstellationBoundaryLines();
 
-    QString constellationName( SkyPoint *p );
+    QString constellationName(SkyPoint *p);
 
-    virtual bool selected();
+    bool selected() Q_DECL_OVERRIDE;
 
-    virtual void preDraw( SkyPainter *skyp );
-private:
-    void appendPoly( PolyList* polyList, int debug=0);
+    void preDraw(SkyPainter *skyp) Q_DECL_OVERRIDE;
 
-    /** @short reads the indices from the KSFileReader instead of using
+  private:
+    void appendPoly(const std::shared_ptr<PolyList> &polyList, int debug = 0);
+
+    /**
+     * @short reads the indices from the KSFileReader instead of using
      * the SkyMesh to create them.  If the file pointer is null or if
      * debug == -1 then we fall back to using the index.
      */
-    void appendPoly( PolyList* polyList, KSFileReader* file, int debug);
+    void appendPoly(std::shared_ptr<PolyList> &polyList, KSFileReader *file, int debug);
 
-    PolyList* ContainingPoly( SkyPoint *p );
+    PolyList *ContainingPoly(SkyPoint *p);
 
-    SkyMesh*   m_skyMesh;
-    PolyIndex  m_polyIndex;
-    int        m_polyIndexCnt;
+    SkyMesh *m_skyMesh { nullptr };
+    PolyIndex m_polyIndex;
+    int m_polyIndexCnt { 0 };
 };
-
-
-#endif
