@@ -31,25 +31,25 @@ class SolarSystemComposite;
  */
 class SolarSystemListComponent : public ListComponent
 {
-public:
-    explicit SolarSystemListComponent( SolarSystemComposite *parent );
+  public:
+    explicit SolarSystemListComponent(SolarSystemComposite *parent);
 
     virtual ~SolarSystemListComponent();
 
-    virtual void update( KSNumbers *num );
+    void update(KSNumbers *num) Q_DECL_OVERRIDE;
 
     /** @short Update the coordinates of the solar system bodies in this component.
-     *
-     * This function updates the position of the moving solar system bodies.
-     * @p data Pointer to the KStarsData object
-     * @p num Pointer to the KSNumbers object
-     */
-    virtual void updateSolarSystemBodies( KSNumbers *num );
+         *
+         * This function updates the position of the moving solar system bodies.
+         * @p data Pointer to the KStarsData object
+         * @p num Pointer to the KSNumbers object
+         */
+    void updateSolarSystemBodies(KSNumbers *num) Q_DECL_OVERRIDE;
 
-protected:
-    void drawTrails( SkyPainter* skyp );
+  protected:
+    void drawTrails(SkyPainter *skyp) Q_DECL_OVERRIDE;
 
-private:
+  private:
     KSPlanet *m_Earth;
 };
 
