@@ -54,21 +54,21 @@ class SkyPointLite;
 
 class QSGTexture;
 
-    /** @class SkyMapLite
-    *
-    *This is the main item that displays all SkyItems. After its instantiation it is reparanted
-    *to an object with objectName SkyMapLiteWrapper in main.qml. To display SkyItems they are reparanted
-    *to instance of SkyMapLite.
-    *
-    *SkyMapLite handles most user interaction events (both mouse and keyboard).
-    *
-    *@short Item for displaying sky objects; also handles user interaction events.
-    *@author Artem Fedoskin
-    *@version 1.0
-    */
-
-class SkyMapLite : public QQuickItem {
+/** @class SkyMapLite
+*
+*This is the main item that displays all SkyItems. After its instantiation it is reparanted
+*to an object with objectName SkyMapLiteWrapper in main.qml. To display SkyItems they are reparanted
+*to instance of SkyMapLite.
+*
+*SkyMapLite handles most user interaction events (both mouse and keyboard).
+*
+*@short Item for displaying sky objects; also handles user interaction events.
+*@author Artem Fedoskin
+*@version 1.0
+*/
 
+class SkyMapLite : public QQuickItem
+{
     Q_OBJECT
     /** magnitude limit. Used in QML **/
     Q_PROPERTY(double magLim READ getMagLim WRITE setMagLim NOTIFY magLimChanged)
@@ -81,31 +81,31 @@ class SkyMapLite : public QQuickItem {
     /** true if SkyMapLite is being panned **/
     Q_PROPERTY(bool slewing READ getSlewing WRITE setSlewing NOTIFY slewingChanged)
     /**
-     * @short true if SkyMapLite is centered on an object and only pinch-to-zoom needs to be available
-    **/
+         * @short true if SkyMapLite is centered on an object and only pinch-to-zoom needs to be available
+        **/
     Q_PROPERTY(bool centerLocked READ getCenterLocked WRITE setCenterLocked NOTIFY centerLockedChanged)
     Q_PROPERTY(bool automaticMode READ getAutomaticMode WRITE setAutomaticMode NOTIFY automaticModeChanged)
     Q_PROPERTY(double skyRotation READ getSkyRotation WRITE setSkyRotation NOTIFY skyRotationChanged)
-protected:
+  protected:
     /** Constructor. **/
     explicit SkyMapLite();
 
     /** Updates SkyMapLite by calling RootNode::update(), which in turn initiates update of all child nodes. **/
-    virtual QSGNode* updatePaintNode(QSGNode *oldNode, UpdatePaintNodeData *updatePaintNodeData);
+    virtual QSGNode *updatePaintNode(QSGNode *oldNode, UpdatePaintNodeData *updatePaintNodeData);
 
     /** pointer to RootNode. Use it to universally access RootNode
-     * @warning RootNode should be used solely during updatePaintNode! See Qt Quick Scene Graph documentation.
-    **/
+         * @warning RootNode should be used solely during updatePaintNode! See Qt Quick Scene Graph documentation.
+        **/
     static RootNode *m_rootNode;
 
-public:
+  public:
     /** Creates instance of SkyMapLite (delete the old one if any) **/
-    static SkyMapLite* createInstance();
+    static SkyMapLite *createInstance();
 
     /** Bind size to parent's size and initialize star images **/
     void initialize(QQuickItem *parent);
 
-    static SkyMapLite* Instance() { return pinstance; }
+    static SkyMapLite *Instance() { return pinstance; }
 
     static bool IsSlewing() { return pinstance->isSlewing(); }
 
@@ -113,135 +113,139 @@ public:
     ~SkyMapLite();
 
     /**
-     * @short skyNode will be deleted on the next call to updatePaintNode (currently used only in
-     * StarNode(struct in StarBlock))
-     */
+         * @short skyNode will be deleted on the next call to updatePaintNode (currently used only in
+         * StarNode(struct in StarBlock))
+         */
     void deleteSkyNode(SkyNode *skyNode);
 
     /** @short Update the focus position according to current options. */
     void updateFocus();
 
     /** @short Retrieve the Focus point; the position on the sky at the
-     *center of the skymap.
-     *@return a pointer to the central focus point of the sky map
-     */
-    SkyPoint* focus() { return &Focus; }
+         *center of the skymap.
+         *@return a pointer to the central focus point of the sky map
+         */
+    SkyPoint *focus() { return &Focus; }
 
     /** @short retrieve the Destination position.
-     *
-     *The Destination is the point on the sky to which the focus will be moved.
-     *@return a pointer to the destination point of the sky map
-     */
-    SkyPoint* destination() { return &Destination; }
+         *
+         *The Destination is the point on the sky to which the focus will be moved.
+         *@return a pointer to the destination point of the sky map
+         */
+    SkyPoint *destination() { return &Destination; }
 
     /** @short retrieve the FocusPoint position.
-     *
-     *The FocusPoint stores the position on the sky that is to be
-     *focused next.  This is not exactly the same as the Destination
-     *point, because when the Destination is set, it will begin slewing
-     *immediately.
-     *
-     *@return a pointer to the sky point which is to be focused next.
-     */
-    SkyPoint* focusPoint() { return &FocusPoint; }
+         *
+         *The FocusPoint stores the position on the sky that is to be
+         *focused next.  This is not exactly the same as the Destination
+         *point, because when the Destination is set, it will begin slewing
+         *immediately.
+         *
+         *@return a pointer to the sky point which is to be focused next.
+         */
+    SkyPoint *focusPoint() { return &FocusPoint; }
 
     /** @short sets the central focus point of the sky map.
-     *@param f a pointer to the SkyPoint the map should be centered on
-     */
-    void setFocus( SkyPoint *f );
+         *@param f a pointer to the SkyPoint the map should be centered on
+         */
+    void setFocus(SkyPoint *f);
 
     /** @short sets the focus point of the skymap, using ra/dec coordinates
-     *
-     *@note This function behaves essentially like the above function.
-     *It differs only in the data types of its arguments.
-     *
-     *@param ra the new right ascension
-     *@param dec the new declination
-     */
-    void setFocus( const dms &ra, const dms &dec );
+         *
+         *@note This function behaves essentially like the above function.
+         *It differs only in the data types of its arguments.
+         *
+         *@param ra the new right ascension
+         *@param dec the new declination
+         */
+    void setFocus(const dms &ra, const dms &dec);
 
     /** @short sets the focus point of the sky map, using its alt/az coordinates
-     *@param alt the new altitude
-     *@param az the new azimuth
-     */
-    void setFocusAltAz( const dms &alt, const dms & az);
+         *@param alt the new altitude
+         *@param az the new azimuth
+         */
+    void setFocusAltAz(const dms &alt, const dms &az);
 
     /** @short sets the destination point of the sky map.
-     *@note setDestination() emits the destinationChanged() SIGNAL,
-     *which triggers the SLOT function SkyMap::slewFocus().  This
-     *function iteratively steps the Focus point toward Destination,
-     *repainting the sky at each step (if Options::useAnimatedSlewing()==true).
-     *@param f a pointer to the SkyPoint the map should slew to
-     */
-    void setDestination( const SkyPoint& f );
+         *@note setDestination() emits the destinationChanged() SIGNAL,
+         *which triggers the SLOT function SkyMap::slewFocus().  This
+         *function iteratively steps the Focus point toward Destination,
+         *repainting the sky at each step (if Options::useAnimatedSlewing()==true).
+         *@param f a pointer to the SkyPoint the map should slew to
+         */
+    void setDestination(const SkyPoint &f);
 
     /** @short sets the destination point of the skymap, using ra/dec coordinates.
-     *
-     *@note This function behaves essentially like the above function.
-     *It differs only in the data types of its arguments.
-     *
-     *@param ra the new right ascension
-     *@param dec the new declination
-     */
-    void setDestination( const dms &ra, const dms &dec );
+         *
+         *@note This function behaves essentially like the above function.
+         *It differs only in the data types of its arguments.
+         *
+         *@param ra the new right ascension
+         *@param dec the new declination
+         */
+    void setDestination(const dms &ra, const dms &dec);
 
     /** @short sets the destination point of the sky map, using its alt/az coordinates.
-     *@param alt the new altitude
-     *@param az the new azimuth
-     */
-    void setDestinationAltAz( const dms &alt, const dms & az);
+         *@param alt the new altitude
+         *@param az the new azimuth
+         */
+    void setDestinationAltAz(const dms &alt, const dms &az);
 
     /** @short set the FocusPoint; the position that is to be the next Destination.
-     *@param f a pointer to the FocusPoint SkyPoint.
-     */
-    void setFocusPoint( SkyPoint *f ) { if ( f ) FocusPoint = *f; }
+         *@param f a pointer to the FocusPoint SkyPoint.
+         */
+    void setFocusPoint(SkyPoint *f)
+    {
+        if (f)
+            FocusPoint = *f;
+    }
 
     /** @short Retrieve the ClickedPoint position.
-     *
-     *When the user clicks on a point in the sky map, the sky coordinates of the mouse
-     *cursor are stored in the private member ClickedPoint.  This function retrieves
-     *a pointer to ClickedPoint.
-     *@return a pointer to ClickedPoint, the sky coordinates where the user clicked.
-     */
-    SkyPoint* clickedPoint() { return &ClickedPoint; }
+         *
+         *When the user clicks on a point in the sky map, the sky coordinates of the mouse
+         *cursor are stored in the private member ClickedPoint.  This function retrieves
+         *a pointer to ClickedPoint.
+         *@return a pointer to ClickedPoint, the sky coordinates where the user clicked.
+         */
+    SkyPoint *clickedPoint() { return &ClickedPoint; }
 
     /** @short Set the ClickedPoint to the skypoint given as an argument.
-     *@param f pointer to the new ClickedPoint.
-     */
-    void setClickedPoint( SkyPoint *f );
+         *@param f pointer to the new ClickedPoint.
+         */
+    void setClickedPoint(SkyPoint *f);
 
     /** @short Retrieve the object nearest to a mouse click event.
-     *
-     *If the user clicks on the sky map, a pointer to the nearest SkyObject is stored in
-     *the private member ClickedObject.  This function returns the ClickedObject pointer,
-     *or NULL if there is no CLickedObject.
-     *@return a pointer to the object nearest to a user mouse click.
-     */
-    SkyObject* clickedObject() const { return ClickedObject; }
+         *
+         *If the user clicks on the sky map, a pointer to the nearest SkyObject is stored in
+         *the private member ClickedObject.  This function returns the ClickedObject pointer,
+         *or nullptr if there is no CLickedObject.
+         *@return a pointer to the object nearest to a user mouse click.
+         */
+    SkyObject *clickedObject() const { return ClickedObject; }
 
     /** @short Set the ClickedObject pointer to the argument.
-     *@param o pointer to the SkyObject to be assigned as the ClickedObject
-     */
-    void setClickedObject( SkyObject *o );
+         *@param o pointer to the SkyObject to be assigned as the ClickedObject
+         */
+    void setClickedObject(SkyObject *o);
 
     /** @short Retrieve the object which is centered in the sky map.
-     *
-     *If the user centers the sky map on an object (by double-clicking or using the
-     *Find Object dialog), a pointer to the "focused" object is stored in
-     *the private member FocusObject.  This function returns a pointer to the
-     *FocusObject, or NULL if there is not FocusObject.
-     *@return a pointer to the object at the center of the sky map.
-     */
-    SkyObject* focusObject() const { return FocusObject; }
+         *
+         *If the user centers the sky map on an object (by double-clicking or using the
+         *Find Object dialog), a pointer to the "focused" object is stored in
+         *the private member FocusObject.  This function returns a pointer to the
+         *FocusObject, or nullptr if there is not FocusObject.
+         *@return a pointer to the object at the center of the sky map.
+         */
+    SkyObject *focusObject() const { return FocusObject; }
 
     /** @short Set the FocusObject pointer to the argument.
-     *@param o pointer to the SkyObject to be assigned as the FocusObject
-     */
-    void setFocusObject( SkyObject *o );
+         *@param o pointer to the SkyObject to be assigned as the FocusObject
+         */
+    void setFocusObject(SkyObject *o);
 
     /** @ Set zoom factor.
-     *@param factor zoom factor
-     */
+         *@param factor zoom factor
+         */
     void setZoomFactor(double factor);
 
     /** @short Call to set up the projector before update of SkyItems positions begins. */
@@ -251,30 +255,30 @@ public:
     int harvardToIndex(char c);
 
     /** @short returns cache of star images
-     *  @return star images cache
-     */
-    QVector<QVector<QPixmap*>> getImageCache();
+         *  @return star images cache
+         */
+    QVector<QVector<QPixmap *>> getImageCache();
 
     /**
-     * @short creates QImage from text and converts it to QSGTexture
-     * @param color text color
-     * @param zoomFont if true zoom-dependent font from SkyLabeler will be used else standart
-     * font is used
-     * @return QSGTexture with text
-     * @note font size is set in SkyLabeler::SkyLabeler() by initializing m_stdFont with default font
-     */
-    QSGTexture *textToTexture(QString text, QColor color = QColor(255,255,255), bool zoomFont = false);
+         * @short creates QImage from text and converts it to QSGTexture
+         * @param color text color
+         * @param zoomFont if true zoom-dependent font from SkyLabeler will be used else standart
+         * font is used
+         * @return QSGTexture with text
+         * @note font size is set in SkyLabeler::SkyLabeler() by initializing m_stdFont with default font
+         */
+    QSGTexture *textToTexture(QString text, QColor color = QColor(255, 255, 255), bool zoomFont = false);
 
     /**
-     * @short returns cached texture from textureCache.
-     *
-     * Use outside of scene graph rendering thread (e.g. not during call to updatePaintNode)
-     * is prohibited!
-     * @param size size of the star
-     * @param spType spectral class
-     * @return cached QSGTexture from textureCache
-     */
-    QSGTexture* getCachedTexture(int size, char spType);
+         * @short returns cached texture from textureCache.
+         *
+         * Use outside of scene graph rendering thread (e.g. not during call to updatePaintNode)
+         * is prohibited!
+         * @param size size of the star
+         * @param spType spectral class
+         * @return cached QSGTexture from textureCache
+         */
+    QSGTexture *getCachedTexture(int size, char spType);
 
     /** @short called when SkyMapComposite finished loading all SkyComponents */
     inline void loadingFinished() { m_loadingFinished = true; }
@@ -292,13 +296,13 @@ public:
     void stopTracking();
 
     /** Get the current projector.
-        @return a pointer to the current projector. */
-    inline const Projector * projector() const { return m_proj; }
+            @return a pointer to the current projector. */
+    inline const Projector *projector() const { return m_proj; }
 
     /**
-     * @short used in QML
-     * @return type of current projection system
-     */
+         * @short used in QML
+         * @return type of current projection system
+         */
     Q_INVOKABLE uint projType() const;
 
     /** Set magnitude limit for size of stars. Used in StarItem **/
@@ -315,118 +319,118 @@ public:
     static double deleteLimit();
 
     /**
-     * @short adds FOV symbol to m_FOVSymbols
-     * @param FOVName name of a FOV symbol
-     */
-    Q_INVOKABLE void addFOVSymbol(const QString& FOVName, bool initialState = false);
+         * @short adds FOV symbol to m_FOVSymbols
+         * @param FOVName name of a FOV symbol
+         */
+    Q_INVOKABLE void addFOVSymbol(const QString &FOVName, bool initialState = false);
 
     /**
-     * @param index of FOVSymbol in m_FOVSymbols
-     * @return true if FOV symbol with name FOVName should be drawn.
-     */
+         * @param index of FOVSymbol in m_FOVSymbols
+         * @return true if FOV symbol with name FOVName should be drawn.
+         */
     bool isFOVVisible(int index);
 
     /**
-      * @param index of FOVSymbol in m_FOVSymbols
-      * @short updates visibility of FOV symbol according to visible
-      */
+          * @param index of FOVSymbol in m_FOVSymbols
+          * @short updates visibility of FOV symbol according to visible
+          */
     Q_INVOKABLE void setFOVVisible(int index, bool visible);
 
     /**
-      * @short this QList should be used as a model in QML to switch on/off FOV symbols
-      **/
+          * @short this QList should be used as a model in QML to switch on/off FOV symbols
+          **/
     Q_INVOKABLE inline QStringList getFOVSymbols() { return m_FOVSymbols; }
 
     /** @short Initializes images of Stars and puts them in cache (copied from SkyQPainter)*/
     void initStarImages();
 
     /**
-     * @short getter for clickedPointLite
-     */
+         * @short getter for clickedPointLite
+         */
     SkyPointLite *getClickedPointLite() { return m_ClickedPointLite; }
 
     /**
-     * @short getter for clickedObjectLite
-     */
+         * @short getter for clickedObjectLite
+         */
     SkyObjectLite *getClickedObjectLite() { return m_ClickedObjectLite; }
 
     /**
-     * @short getter for centerLocked
-     */
+         * @short getter for centerLocked
+         */
     bool getCenterLocked() { return m_centerLocked; }
 
     /**
-     * @short Proxy method for SkyMapDrawAbstract::drawObjectLabels()
-     */
+         * @short Proxy method for SkyMapDrawAbstract::drawObjectLabels()
+         */
     //inline void drawObjectLabels( QList< SkyObject* >& labelObjects ) { dynamic_cast<SkyMapDrawAbstract *>(m_SkyMapDraw)->drawObjectLabels( labelObjects ); }
 
     /**
-     * @return true if SkyMapLite is being slewed
-     */
+         * @return true if SkyMapLite is being slewed
+         */
     bool getSlewing() const { return m_slewing; }
 
     /**
-     * @short sets whether SkyMapLite is being slewed
-     */
+         * @short sets whether SkyMapLite is being slewed
+         */
     void setSlewing(bool newSlewing);
 
     /**
-     * @short sets whether SkyMapLite is centered on an object and locked(olny pinch-to-zoom is available)
-     */
+         * @short sets whether SkyMapLite is centered on an object and locked(olny pinch-to-zoom is available)
+         */
     void setCenterLocked(bool centerLocked);
 
     /** True if automatic mode is on (SkyMapLite is controled by smartphones accelerometer magnetometer) **/
     bool getAutomaticMode() const { return m_automaticMode; }
 
     /**
-     * @short switch automatic mode on/off according to isOn parameter
-     */
+         * @short switch automatic mode on/off according to isOn parameter
+         */
     Q_INVOKABLE void setAutomaticMode(bool automaticMode);
 
     double getSkyRotation() const { return m_skyRotation; }
 
-public slots:
-     /** Called whenever wrappers' width or height are changed. Probably will be used to
-     * update positions of items.
-     */
+  public slots:
+    /** Called whenever wrappers' width or height are changed. Probably will be used to
+        * update positions of items.
+        */
     void resizeItem();
 
     /** Recalculates the positions of objects in the sky, and then repaints the sky map.
-     */
+         */
     void forceUpdate();
 
     /** @short Left for compatibility reasons
-     * @see forceUpdate()
-     */
+         * @see forceUpdate()
+         */
     void forceUpdateNow() { forceUpdate(); }
 
     /**
-     * @short Update the focus point and call forceUpdate()
-     * @param now is saved for compatibility reasons
-     */
-    void slotUpdateSky( bool now );
+         * @short Update the focus point and call forceUpdate()
+         * @param now is saved for compatibility reasons
+         */
+    void slotUpdateSky(bool now);
 
     /** Step the Focus point toward the Destination point.  Do this iteratively, redrawing the Sky
-     * Map after each step, until the Focus point is within 1 step of the Destination point.
-     * For the final step, snap directly to Destination, and redraw the map.
-     */
+         * Map after each step, until the Focus point is within 1 step of the Destination point.
+         * For the final step, snap directly to Destination, and redraw the map.
+         */
     void slewFocus();
 
     /** @short Center the display at the point ClickedPoint.
-     *
-     * The essential part of the function is to simply set the Destination point, which will emit
-     * the destinationChanged() SIGNAL, which triggers the slewFocus() SLOT.  Additionally, this
-     * function performs some bookkeeping tasks, such updating whether we are tracking the new
-     * object/position, adding a Planet Trail if required, etc.
-     *
-     * @see destinationChanged()
-     * @see slewFocus()
-     */
+         *
+         * The essential part of the function is to simply set the Destination point, which will emit
+         * the destinationChanged() SIGNAL, which triggers the slewFocus() SLOT.  Additionally, this
+         * function performs some bookkeeping tasks, such updating whether we are tracking the new
+         * object/position, adding a Planet Trail if required, etc.
+         *
+         * @see destinationChanged()
+         * @see slewFocus()
+         */
     void slotCenter();
 
     /** Checks whether the timestep exceeds a threshold value.  If so, sets
-     * ClockSlewing=true and sets the SimClock to ManualMode.
-     */
+         * ClockSlewing=true and sets the SimClock to ManualMode.
+         */
     void slotClockSlewing();
 
     /** Zoom in one step. */
@@ -438,25 +442,24 @@ public slots:
     /** Set default zoom. */
     void slotZoomDefault();
     /**
-     * @short centres skyObj in SkyMap and opens context drawer with skyObj
-     * Used in FindDialogLite
-     */
+         * @short centres skyObj in SkyMap and opens context drawer with skyObj
+         * Used in FindDialogLite
+         */
     void slotSelectObject(SkyObject *skyObj);
 
-#if defined(Q_OS_ANDROID)
     /** @short updates focus of SkyMapLite according to data from DeviceOrientation
-        (Smartphone's sensors)*/
+            (Smartphone's sensors)*/
     void updateAutomaticMode();
-#endif
+
     void setSkyRotation(double skyRotation);
 
-signals:
+  signals:
     /** Emitted by setDestination(), and connected to slewFocus().  Whenever the Destination
-     * point is changed, slewFocus() will iteratively step the Focus toward Destination
-     * until it is reached.
-     * @see SkyMap::setDestination()
-     * @see SkyMap::slewFocus()
-     */
+         * point is changed, slewFocus() will iteratively step the Focus toward Destination
+         * until it is reached.
+         * @see SkyMap::setDestination()
+         * @see SkyMap::slewFocus()
+         */
     void destinationChanged();
 
     /** Emitted when zoom level is changed. */
@@ -475,10 +478,10 @@ signals:
     void positionChanged();
 
     /** Emitted when position under mouse changed. */
-    void mousePointChanged(SkyPoint*);
+    void mousePointChanged(SkyPoint *);
 
     /** Emitted when a position is clicked */
-    void positionClicked(SkyPoint*);
+    void positionClicked(SkyPoint *);
 
     /** Emitted when user clicks on SkyMapLite (analogous to positionClicked but sends QPoint) */
     void posClicked(QPointF pos);
@@ -498,68 +501,69 @@ signals:
 
     /** Emited when skyRotation used to rotate coordinates of SkyPoints is changed **/
     void skyRotationChanged(double skyRotation);
-protected:
+
+  protected:
     /** Process keystrokes:
-     * @li arrow keys  Slew the map
-     * @li +/- keys  Zoom in and out
-     * @li <i>Space</i>  Toggle between Horizontal and Equatorial coordinate systems
-     * @li 0-9  Go to a major Solar System body (0=Sun; 1-9 are the major planets, except 3=Moon)
-     * @li [  Place starting point for measuring an angular distance
-     * @li ]  End point for Angular Distance; display measurement.
-     * @li <i>Escape</i>  Cancel Angular measurement
-     * @li ,/<  Step backward one time step
-     * @li ./>  Step forward one time step
-     */
+         * @li arrow keys  Slew the map
+         * @li +/- keys  Zoom in and out
+         * @li <i>Space</i>  Toggle between Horizontal and Equatorial coordinate systems
+         * @li 0-9  Go to a major Solar System body (0=Sun; 1-9 are the major planets, except 3=Moon)
+         * @li [  Place starting point for measuring an angular distance
+         * @li ]  End point for Angular Distance; display measurement.
+         * @li <i>Escape</i>  Cancel Angular measurement
+         * @li ,/<  Step backward one time step
+         * @li ./>  Step forward one time step
+         */
     //virtual void keyPressEvent( QKeyEvent *e );
 
     /** When keyRelease is triggered, just set the "slewing" flag to false,
-     * and update the display (to draw objects that are hidden when slewing==true). */
+         * and update the display (to draw objects that are hidden when slewing==true). */
     //virtual void keyReleaseEvent( QKeyEvent *e );
 
     /** Determine RA, Dec coordinates of clicked location.  Find the SkyObject
-     * which is nearest to the clicked location.
-     *
-     * If left-clicked: Set set mouseButtonDown==true, slewing==true; display
-     * nearest object name in status bar.
-     * If right-clicked: display popup menu appropriate for nearest object.
-     */
-    virtual void mousePressEvent( QMouseEvent *e );
+         * which is nearest to the clicked location.
+         *
+         * If left-clicked: Set set mouseButtonDown==true, slewing==true; display
+         * nearest object name in status bar.
+         * If right-clicked: display popup menu appropriate for nearest object.
+         */
+    virtual void mousePressEvent(QMouseEvent *e);
 
     /** set mouseButtonDown==false, slewing==false */
-    virtual void mouseReleaseEvent( QMouseEvent *e );
+    virtual void mouseReleaseEvent(QMouseEvent *e);
 
     /** Center SkyMap at double-clicked location  */
-    virtual void mouseDoubleClickEvent( QMouseEvent *e );
+    virtual void mouseDoubleClickEvent(QMouseEvent *e);
 
     /** This function does several different things depending on the state of the program:
-     * @li If Angle-measurement mode is active, update the end-ruler point to the mouse cursor,
-     *     and continue this function.
-     * @li If we are defining a ZoomBox, update the ZoomBox rectangle, redraw the screen,
-     *     and return.
-     * @li If dragging the mouse in the map, update focus such that RA, Dec under the mouse
-     *     cursor remains constant.
-     * @li If just moving the mouse, simply update the curso coordinates in the status bar.
-     */
-    virtual void mouseMoveEvent( QMouseEvent *e );
+         * @li If Angle-measurement mode is active, update the end-ruler point to the mouse cursor,
+         *     and continue this function.
+         * @li If we are defining a ZoomBox, update the ZoomBox rectangle, redraw the screen,
+         *     and return.
+         * @li If dragging the mouse in the map, update focus such that RA, Dec under the mouse
+         *     cursor remains constant.
+         * @li If just moving the mouse, simply update the curso coordinates in the status bar.
+         */
+    virtual void mouseMoveEvent(QMouseEvent *e);
 
     /** Zoom in and out with the mouse wheel. */
-    virtual void wheelEvent( QWheelEvent *e );
+    virtual void wheelEvent(QWheelEvent *e);
 
     /**
-     * @short this function handles zooming in and out using "pinch to zoom" gesture
-     */
-    virtual void touchEvent( QTouchEvent *e);
+         * @short this function handles zooming in and out using "pinch to zoom" gesture
+         */
+    virtual void touchEvent(QTouchEvent *e);
 
-private slots:
+  private slots:
     /** @short display tooltip for object under cursor. It's called by m_HoverTimer.
-     *  if mouse didn't moved for last HOVER_INTERVAL milliseconds.
-     */
+         *  if mouse didn't moved for last HOVER_INTERVAL milliseconds.
+         */
     //void slotTransientLabel();
 
     /** Set the shape of mouse cursor to a cross with 4 arrows. */
     void setMouseMoveCursor();
-private:
 
+  private:
     /** @short Sets the shape of the default mouse cursor to a cross. */
     void setDefaultMouseCursor();
 
@@ -567,39 +571,39 @@ private:
     void setZoomMouseCursor();
 
     /** Calculate the zoom factor for the given keyboard modifier
-     */
-    double zoomFactor( const int modifier );
+         */
+    double zoomFactor(const int modifier);
 
     /** calculate the magnitude factor (1, .5, .2, or .1) for the given
-     * keyboard modifier.
-     */
-    double magFactor( const int modifier );
+         * keyboard modifier.
+         */
+    double magFactor(const int modifier);
 
     /** Decrease the magnitude limit by a step size determined by the
-     * keyboard modifier.
-     * @param modifier
-     */
-    void decMagLimit( const int modifier );
+         * keyboard modifier.
+         * @param modifier
+         */
+    void decMagLimit(const int modifier);
 
-     /** Increase the magnitude limit by a step size determined by the
-     * keyboard modifier.
-     * @param modifier
-     */
-    void incMagLimit( const int modifier );
+    /** Increase the magnitude limit by a step size determined by the
+        * keyboard modifier.
+        * @param modifier
+        */
+    void incMagLimit(const int modifier);
 
     /** Convenience routine to either zoom in or increase mag limit
-     * depending on the Alt modifier.  The Shift and Control modiifers
-     * will adjust the size of the zoom or the mag step.
-     * @param modifier
-     */
-    void zoomInOrMagStep( const int modifier );
+         * depending on the Alt modifier.  The Shift and Control modiifers
+         * will adjust the size of the zoom or the mag step.
+         * @param modifier
+         */
+    void zoomInOrMagStep(const int modifier);
 
     /** Convenience routine to either zoom out or decraase mag limit
-     * depending on the Alt modifier.  The Shift and Control modiifers
-     * will adjust the size of the zoom or the mag step.
-     * @param modifier
-     */
-    void zoomOutOrMagStep( const int modifier );
+         * depending on the Alt modifier.  The Shift and Control modiifers
+         * will adjust the size of the zoom or the mag step.
+         * @param modifier
+         */
+    void zoomOutOrMagStep(const int modifier);
 
     //True if SkyMapLite was initialized (star images were initialized etc.)
     bool isInitialized;
@@ -631,11 +635,11 @@ private:
     bool m_loadingFinished;
 
     /** @short Coordinates of point under cursor. It's update in
-     * function mouseMoveEvent
-     */
+         * function mouseMoveEvent
+         */
     SkyPoint m_MousePoint;
 
-    SkyPoint  Focus, ClickedPoint, FocusPoint, Destination;
+    SkyPoint Focus, ClickedPoint, FocusPoint, Destination;
     SkyObject *ClickedObject, *FocusObject;
 
     SkyPointLite *m_ClickedPointLite;
@@ -654,7 +658,7 @@ private:
     bool m_objPointingMode;
     bool m_fovCaptureMode;
 
-    Projector* m_proj;
+    Projector *m_proj;
 
     static SkyMapLite *pinstance;
     QQuickItem *m_SkyMapLiteWrapper;
@@ -663,7 +667,7 @@ private:
     QLinkedList<SkyNode *> m_deleteNodes;
 
     float m_sizeMagLim; //Used in PointSourceNode
-    double m_magLim; //Mag limit for all objects
+    double m_magLim;    //Mag limit for all objects
 
     /// Used to notify zoom-dependent labels about font size change
     bool m_fontSizeChanged;
@@ -671,7 +675,7 @@ private:
     QPainter m_painter;
 
     /** This timer is triggered every time user touches the screen with one finger. If touch was released
-        within 500 milliseconds than it is a tap, otherwise we pan. **/
+            within 500 milliseconds than it is a tap, otherwise we pan. **/
     QTimer m_tapBeganTimer;
 
     static int starColorMode;
@@ -690,9 +694,9 @@ private:
 
     //This can be later changed
     // Cache for star images.
-    QVector<QVector<QPixmap*>> imageCache;
+    QVector<QVector<QPixmap *>> imageCache;
     //Textures created from cached star images
-    QVector<QVector<QSGTexture*>> textureCache;
+    QVector<QVector<QSGTexture *>> textureCache;
     bool clearTextures;
 
     bool tapBegan;
@@ -703,12 +707,18 @@ private:
 
     double m_skyRotation;
 
-    enum class SkyMapOrientation { Top0, Right90, Bottom180, Left270 };
+    enum class SkyMapOrientation
+    {
+        Top0,
+        Right90,
+        Bottom180,
+        Left270
+    };
     SkyMapOrientation m_skyMapOrientation;
 
-#if defined (Q_OS_ANDROID)
+#if defined(Q_OS_ANDROID)
     QTimer automaticModeTimer;
-    DeviceOrientation* m_deviceOrientation;
+    DeviceOrientation *m_deviceOrientation;
 #endif
 };
 
