@@ -15,65 +15,62 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef SATELLITEGROUP_H
-#define SATELLITEGROUP_H
-
+#pragma once
 
 #include <QString>
-
 #include <QUrl>
-#include "skyobjects/satellite.h"
-#include "skypainter.h"
 
+class Satellite;
 
 /**
-    *@class SatelliteGroup
-    *Represents a group of artificial satellites.
-    *@author Jérôme SONRIER
-    *@version 1.0
-    */
-class SatelliteGroup : public QList<Satellite*>
+ * @class SatelliteGroup
+ * Represents a group of artificial satellites.
+ * @author Jérôme SONRIER
+ * @version 1.0
+ */
+class SatelliteGroup : public QList<Satellite *>
 {
-public:
+  public:
     /**
-     *@short Constructor
+     * @short Constructor
      */
-    SatelliteGroup( QString name, QString tle_filename, QUrl update_url );
+    SatelliteGroup(const QString& name, const QString& tle_filename, const QUrl& update_url);
 
     /**
-     *@short Destructor
+     * @short Destructor
      */
     ~SatelliteGroup();
 
     /**
-     *Read TLE file of the group and create all satellites found in the file.
+     * Read TLE file of the group and create all satellites found in the file.
      */
     void readTLE();
 
     /**
-     *Compute current position of the each satellites in the group.
+     * Compute current position of the each satellites in the group.
      */
     void updateSatellitesPos();
 
     /**
-     *@return TLE filename
+     * @return TLE filename
      */
     QUrl tleFilename();
 
     /**
-     *@return URL from which new TLE file must be download
+     * @return URL from which new TLE file must be download
      */
     QUrl tleUrl();
 
     /**
-     *@return Name of the group
+     * @return Name of the group
      */
     QString name();
 
-private:
-    QString m_name;             // Group name
-    QString m_tle_file;         // TLE filename
-    QUrl    m_tle_url;          // URL used to update TLE file
+  private:
+    /// Group name
+    QString m_name;
+    /// TLE filename
+    QString m_tle_file;
+    /// URL used to update TLE file
+    QUrl m_tle_url;
 };
-
-#endif
