@@ -28,22 +28,21 @@
   * Inherits QWidget
   *@author Pablo de Vicente
   */
-class modCalcEclCoords : public QFrame, public Ui::modCalcEclCoordsDlg  {
-
+class modCalcEclCoords : public QFrame, public Ui::modCalcEclCoordsDlg
+{
     Q_OBJECT
 
-public:
-
+  public:
     modCalcEclCoords(QWidget *p);
     ~modCalcEclCoords();
 
-public slots:
+  public slots:
     void slotNow(void);
     void slotObject(void);
     void slotDateTimeChanged(const QDateTime &edt);
     void slotCompute(void);
-private:
+
+  private:
     KStarsDateTime kdt;
 };
 #endif
-
