@@ -44,22 +44,22 @@ class KSSun;
  * display a nice table
  */
 
-class MoonPhaseTool : public QDialog {
-
+class MoonPhaseTool : public QDialog
+{
     Q_OBJECT
 
-public:
+  public:
     MoonPhaseTool(QWidget *p);
     ~MoonPhaseTool();
 
     /*
-public slots:
+        public slots:
 
-    void slotUpdate();
-    void slotSetMonth();
-    */
+        void slotUpdate();
+        void slotSetMonth();
+        */
 
-private:
+  private:
     KSMoon *m_Moon;
     KSSun *m_Sun;
     KSNumbers *m_Num;
